package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,``P`!````4!8``#0````DP0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````+*X`
M`"RN```%`````!````$```"XO0``N,T``+C-``!8`@``G!(```8`````$```
M`@```,2]``#$S0``Q,T```@!```(`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&2`GP``@)\``("?``#L````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DN+T`
M`+C-``"XS0``2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`LGK,=;/<ANZ=Y1F;^;!EWM;O]*P1````3`````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````3````%````!4````50``
M`%L```!<````70```%\```!@`````````&(```!D````90```&8`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"^`@``````
M```````2````;`,`````````````$@```!,"`````````````!(````1````
M```````````@````A0,`````````````$0```/D#`````````````!(````+
M`P`````````````1````70,`````````````$@```"4!`````````````!(`
M``#9`@`````````````2````R```````````````$@```)<!````````````
M`!(```#%`@`````````````2````F```````````````$@```"`!````````
M`````!(```"/`P`````````````2````$@,`````````````$@```!4!````
M`````````!$```"-`@`````````````2````>P$`````````````$@```/<`
M`````````````!$````9`P`````````````2````20$`````````````$@``
M`-8``````````````!(```!``P`````````````B````Q0$`````````````
M$@```%P"`````````````!(````+`@`````````````2````J0(`````````
M````$@```+(!`````````````!(```":`@`````````````2````O@$`````
M````````$@```%<!`````````````!(````B`P`````````````2````+0``
M````````````(````&X"`````````````!(```#0`0`````````````1````
M+P,`````````````$@```'@``````````````!(```"W`@`````````````2
M````<P,`````````````$@````0"`````````````!(```"G````````````
M```2````LP``````````````$@```'`!`````````````!(```"4`@``````
M```````2````>P(`````````````$@```#8!`````````````!(````L`@``
M```````````2````H@(`````````````$@```&H``````````````!(````J
M`0`````````````2````X`(`````````````$@```*<!`````````````!(`
M```$`0`````````````2````90,`````````````$@```+`"````````````
M`!(```"&`P`````````````A````B0$`````````````$@```(<`````````
M`````!(````\```````````````@````Z```````````````$@```&<!````
M`````````!(````V`P`````````````2````RP(`````````````$@```%``
M`````````````"````!S`@`````````````2````AP,`````````````$0``
M``$#`````````````!(````8`@`````````````2````[@(`````````````
M$@```#T"`````````````!(```"$`@`````````````2````^0(`````````
M````$@```$\#`````````````!(````"!```@%T``'L````2``T`T`,``,1>
M````````$@`.`"<$``#03```*0T``!(`#0"``P``$!0``$`"```2``T`U@,`
M`(!%```%````$@`-`(T$``"010``'0(``!(`#0"'!```[!$````````2``H`
MN@0```!:``"``P``$@`-`+4#```0T````````!``&``.!```L$<``"(````2
M``T`30(``-Q>```$````$0`/`,$#``!4X````````!``&`"%!```$$0``#L`
M```2``T`F@0``'!+``!:`0``$@`-`*P$``"P2@``>0```!(`#0`T!````-``
M```````0`!<`&P0``.!'``#L````$@`-`*X#```0T````````!``%P!G!```
M#-````0````1`!<`Q@,``*!>```"````$@`-`%<$``!`7@``70```!(`#0`Z
M!```4!8````````2``T`-@0```#0````````(``7`'$$``#87@``!````!$`
M#P#G`P``,$L``#0````2``T`000``+!$``#)````$@`-`'@$``#02```V0$`
M`!(`#0``;&EB<&5R;"YS;RXU+C(T`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D
M`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L
M:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI
M=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`
M7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M
M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`%]?<W1A8VM?8VAK7V9A:6P`;&EB8W)Y<'0N<V\N
M,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R
M7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER
M`%]?9&%T85]S=&%R=`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S
M=5]I;FET`&UY7W!A<E]P;`!?9G!?:'<`<&%R7VEN:71?96YV`'AS7VEN:70`
M<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`
M6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)
M0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXT````
M`@`"``,````"``(``@`"``(``@```````@``````!``"`````@```````@``
M````!0````8`!P`"`````@`"````"`````(````"`````@`"``<`````````
M`@`"`````P`"```````(```````"``(``@``````````````"0`(`````@`"
M``D``P`)``,``@`"``@``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`"`/0!```0````,````!)I:0T`
M``<`T`0``!`````0:6D-```#`-H$`````````0`&`$,"```0`````````!)I
M:0T```D`T`0``!````!T&6D)```(`.0$```0````<AEI"0``!@#P!```$```
M`',?:0D```4`_`0``!`````4:6D-```$``@%```0````$&EI#0```@#:!```
M`````+C-```(````O,T```@```"TSP``"`````30```(````#-````@```#8
MS@``!@$``-S.```&`@``X,X```8#``#DS@``!@0``.C.```&!@``[,X```8'
M``#PS@``!@@``/3.```&"0``^,X```8*``#\S@``!@L```#/```&#```!,\`
M``8-```(SP``!@X```S/```&#P``$,\```80```4SP``!A$``!C/```&$@``
M',\```83```@SP``!A0``"3/```&%0``*,\```86```LSP``!A<``##/```&
M&```-,\```89```XSP``!AH``#S/```&&P``0,\```8<``!$SP``!AT``$C/
M```&'@``3,\```8?``!0SP``!B```%3/```&(0``6,\```8B``!<SP``!B,`
M`&#/```&)```9,\```8E``!HSP``!B8``&S/```&)P``<,\```8H``!TSP``
M!BD``'C/```&*@``?,\```8K``"`SP``!BP``(3/```&+0``B,\```8N``",
MSP``!B\``)#/```&,```E,\```8Q``"8SP``!C(``)S/```&,P``H,\```8T
M``"DSP``!C4``*C/```&-@``K,\```8W``"PSP``!C@``+C/```&.0``O,\`
M``8[``#`SP``!CP``,3/```&/0``R,\```8^``#,SP``!C\``-#/```&0```
MU,\```9!``#8SP``!D(``-S/```&0P``X,\```9$``#DSP``!D4``.C/```&
M1@``[,\```9'``#PSP``!D@``/3/```&20``^,\```9*``#\SP``!DL``%.#
M[`CHFP0``('#U[P``(N#D````(7`=`7H]@```(/$"%O#`/^S!````/^C"```
M``````#_HPP```!FD/^C$````&:0_Z,4````9I#_HQP```!FD/^C)````&:0
M_Z,H````9I#_HRP```!FD/^C,````&:0_Z,X````9I#_HSP```!FD/^C0```
M`&:0_Z-$````9I#_HT@```!FD/^C4````&:0_Z-4````9I#_HUP```!FD/^C
M8````&:0_Z-D````9I#_HV@```!FD/^C;````&:0_Z-P````9I#_HW0```!F
MD/^C>````&:0_Z-\````9I#_HX````!FD/^CA````&:0_Z.(````9I#_HXP`
M``!FD/^CD````&:0_Z.4````9I#_HYP```!FD/^CH````&:0_Z.D````9I#_
MHZ@```!FD/^CK````&:0_Z.P````9I#_H[0```!FD/^CN````&:0_Z.\````
M9I#_H\````!FD/^CR````&:0_Z/,````9I#_H]````!FD/^CU````&:0_Z/8
M````9I#_H]P```!FD/^CX````&:0_Z/D````9I#_H^P```!FD/^C\````&:0
M_Z/\````9I#_HP`!``!FD/^C!`$``&:0_Z,(`0``9I#_HQ`!``!FD/^C&`$`
M`&:0_Z,<`0``9I#_HR`!``!FD/^C)`$``&:0_Z,H`0``9I#_HRP!``!FD/^C
M,`$``&:0C4PD!(/D\/]Q_%6)Y5=64U&)SNAH`@``@<.DN@``@^PLBT$$B474
MBT$(B4709:$4````B47D,<"-1=!0C4744%'HPO[__XN#Q````(/$#%!0_[/T
M````Z)1)``"+@U@```"#Q!"`.``/A"8!``"+NTP```"#[`S_-^A2____@(CZ
M`@```EK_-^A#____@(CZ`@```8L&@\00@\`%/?___S\/AUD!``"#[`S!X`)0
MZ!7^__^+?=2+-H/$$(F#>!$``,>#?!$```0```"+%X/^`8D0C9,*DO__B5`$
MBY-``0``B5`(C9,-DO__B5`,N@$```!^$HUT)@"+#)>)3)`,@\(!.=9U\H/L
M#,=$L`P`````@\8#:@!0C8.$=?__5E#_LX01``#H3O[__X/$((7`B<8/A)8`
M``"#[`S_LX01``"-?>#H./W__XV#LY#__XGZZ/LG``"#Q!"%P`^$A0```(/L
M#/^SA!$``.CR_/__Z.W]__^#Q!")\(M]Y&4S/10````/A:D```"-9?!96UY?
M78UA_,/H#_W__X7`B8.$$0``#X2/````@^P,4.BH_/__B[M,````6?\WZ!+^
M__^#Q!#&@&D%````Z:?^__^#[`S_LX01``#HS?W__X/$$(G&Z5+___^+@X`1
M``"%P'0E@^P,4.AX1P``@\00Z6#___]04(V#8Y#___^SF````%#H'/W__XV#
M:)#__XGZZ"\G``"%P(F#@!$```^$,?___^N^Z&I(``"#[`QJ`>BX_/__,>U>
MB>&#Y/!05%+H(@```('#;+@``(V#U(___U"-@W2/__]045;_L^@```#HI_S_
M__2+'"3#9I!FD&:09I!FD(L<),-FD&:09I!FD&:09I#H%P$``('")[@``(V*
M1`$``(V"1P$``"G(@_@&=A>+@A@```"%P'0-58GE@^P44?_0@\00R?/#B?:-
MO"<`````Z-<```"!PN>W``!5C8I$`0``C8)$`0``B>53*<C!^`*#[`2)P\'K
M'P'8T?AT%(N2#`$``(72=`J#[`A04?_2@\00BUW\R<.)]HV\)P````!5B>53
MZ%?___^!PY.W``"#[`2`NU0!````=2>+@V@```"%P'01@^P,_[,X`0``Z$W[
M__^#Q!#H-?___\:#5`$```&+7?S)PXGVC;PG`````.@W````@<)'MP``C8+T
M_O__BPB%R74)Z43___^-="8`BY+X````A=)T[56)Y8/L%%#_TH/$$,GI)/__
M_XL4),-55XUH.%93@>P,`P``B40D3(U$)'B)="0098L=%````(F<)/P"```Q
MVXE$)`B)?"04B<&0C70F`(M4G0"+1)T$QT39!`````#'1-D,`````,=$)`0`
M````#\J)!"2)%-F)PL'H&,'J"('B`/\```G0BQ0DB<>+!"3!XAC!X`@)UR4`
M`/\`"?B)1-D(@\,"@_L0=:6+1"0(C90D>`(``(D4)(G%D(UT)@"+56B+16R#
MQ0@S53@S13PS50@S10PS5?@S1?S'17P`````B<>)T(G1#ZSX'P'1"<&)37@[
M+"1UR(M$)$R+<`R+2!R+6`B+.(MH!(M0&(ET)!R)3"0,BW`4BT@@B5PD&(M8
M$(EL)!2)5"0(,=*)3"18B70D!(GYB?Z)'"2+6"0/K.D;P>8%B7PD$(GUBW0D
M6(E<)%P)S0-T)'B+?"1<$WPD?(GHB?&!P9EY@EJ)^X/3``'(BTPD&!':BQPD
MB40D((E4)"2+5"0(B=\QUR'/B?J+?"0(BW0D((M$)!C'1"0D`````,=$)#0`
M````,?H!UHM4)!R)QXET)"")="0HP><>B<:)^8M\)`@/K-8"B<V+!"2+5"0D
M"?4#O"2`````B6PD,(ML)`P3K"2$````B?F!P9EY@EJ)ZXML)#")3"0X@],`
MBTPD.(E<)#S'1"0\`````#'%BT0D$(GO(<>+1"0@B?N+/"2)QC'[B<>+1"00
M`=G!Y@6)="0XBW0D.(G+#ZS7&XM4)!2)P0G^`?/!X1XQ_P^LT`*)S8M4)#")
M7"10"<6);"0XBVPD(/?5(>J+;"0H(VPD.,=$)"P`````QT0D1`````")Z(G5
MBU0D)`G%BP0D`X0DB````(GIQT0D)``````%F7F"6@'!B=C!X`6)1"0HB=B+
M;"0H#ZSX&XE$)$`+;"1`BT0D(`'IB4PD*(E,)&")P<'A'@^LT`*)S8M4)#@)
MQ8M$)#");"1`B=WWU2'JBVPD4"-L)$`)Z@.$))````")T8M4)"P%F7F"6@'!
MBT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$)#`+;"0P`>F)_8G?#ZSO`L'B
M'HE,)%")3"0@B=4)_8EL)##'1"0T`````(ML)"B+5"1`BW0D.,=$)#P`````
M]]4AZHML)&`C;"0PB>B)U8M4)"0)Q0.T))@```")Z8GP!9EY@EH!P8M$)"")
MRXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!QT0D+``````)_@'SP>$>
M,?\/K-`"B<V+5"0PB5PD8`G%BT0D0(EL)#B+;"0@]]4AZHML)%`C;"0X">H#
MA"2@````B=&+5"0D!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"1`"VPD
M0(M$)"`!Z8E,)%")3"0HB<'!X1X/K-`"B<V)V@G%]]*);"1`(U0D.(ML)&`C
M;"1`BT0D,(MT)#C'1"0D`````,=$)$0`````QT0D-``````)Z@.$)*@```")
MT8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$)#`+;"0P
M`>F)_8G?#ZSO`L'B'HE,)"")3"1@B=6+5"1`"?V);"0PBVPD*/?5(>J+;"10
M(VPD,(GHB=6+5"0D"<4#M"2P````B>F)\`69>8):`<&+1"0@B<N)QHG'BT0D
M*,'F!8ET)#B+="0X#ZS7&XG!"?X!\\'A'C'_B5PD4(M4)"R)S<=$)"P`````
MQT0D/`````#'1"1$``````^LT`*+5"0P"<6+1"1`B6PD.(ML)"#WU2'JBVPD
M8"-L)#@)Z@.$)+@```")T8M4)"0%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX
M&XE$)$`+;"1`BT0D(`'IB4PD*(E,)&")P<'A'@^LT`*)S8G:"<7WTB-4)#B)
M;"1`BVPD4"-L)$"+1"0P">H#A"3`````B=&+5"0L!9EY@EH!P8M$)"C!X`6)
M1"0@BT0D*`^LT!N)VHE$)#"+;"0@"VPD,(MT)#C'1"0D`````,=$)#0`````
MQT0D/``````!Z8G]B=\/K.\"P>(>B4PD((E,)%")U8M4)$`)_8EL)#"+;"0H
M]]4AZHML)&`C;"0PB>B)U8M4)"0)Q0.T),@```")Z8GP!9EY@EH!P8M$)"")
MRXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-
MBU0D,(E<)&`)Q8M$)$");"0XBVPD(/?5(>J+;"10(VPD.`GJ`X0DT````(G1
M!9EY@EH!P8G8P>`%B40D*(G8#ZSX&XE$)$"+;"0H"VPD0(M$)""+5"0DQT0D
M+`````#'1"1$`````,=$)"0`````QT0D-`````"+="0X`>F)3"0HB4PD4(G!
MP>$>#ZS0`HG-B=H)Q??2(U0D.(EL)$"+;"1@(VPD0(M$)#`)Z@.$)-@```")
MT8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)VHE$)#`+;"0P
M`>F)_8G?#ZSO`L'B'HE,)&")3"0@B=6+5"1`"?V);"0PBVPD*/?5(>J+;"10
M(VPD,(GHB=4)Q0.T).````"+5"0DB>G'1"0\`````,=$)$0`````B?`%F7F"
M6@'!BT0D((G+B<:)QXM$)"C!Y@6)="0XBW0D.`^LUQN+5"0LB<''1"0L````
M``G^`?/!X1XQ_P^LT`*)S8M4)#")7"10"<6+1"1`B6PD.(ML)"#WU2'JBVPD
M8"-L)#@)Z@.$).@```")T8M4)"0%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX
M&XE$)$`+;"1`BT0D(`'IB4PD8(E,)"B)P<'A'@^LT`*)S8G:"<7WTB-4)#B)
M;"1`BVPD4"-L)$"+1"0PBW0D.,=$)"0`````QT0D-`````#'1"0\``````GJ
M`X0D\````(G1BU0D+`69>8):`<&+1"0HP>`%B40D((M$)"B+;"0@#ZS0&XG:
MB40D,`ML)#`!Z8G]B=\/K.\"P>(>B4PD((E,)%")U8M4)$`)_8EL)#"+;"0H
M]]4AZHML)&`C;"0PB>B)U8M4)"0)Q0.T)/@```")Z8GP!9EY@EH!P8M$)"")
MRXG&B<>+1"0HP>8%B70D.(MT)#@/K-<;BU0D+(G!"?X!\\'A'C'_#ZS0`HG-
MB5PD8`G%B6PD.(ML)""+5"0PBT0D0,=$)"P`````]]4AZHML)%`C;"0X">H#
MA"0``0``B=&+5"0DQT0D)``````%F7F"6@'!B=C!X`6)1"0HB=B+;"0H#ZSX
M&XE$)$`+;"1`BT0D(`'IB4PD*(E,)%")P<'A'@^LT`*)S8G:"<7WTB-4)#B)
M;"0@BVPD8"-L)""+1"0P">H#A"0(`0``B=&+5"0L!9EY@EH!P8M$)"C!X`6)
M1"0PBT0D*(ML)#`/K-`;B=J)1"1`"VPD0`'IB?V)WP^L[P+!XAZ)3"1@B4PD
M,,=$)#0`````BVPD*(G3BU0D(`G[BW0D.(E<)&B)7"1`]]7'1"1$`````,=$
M)"0`````(>J+;"10(=V)Z(G5BU0D-`G%`[0D$`$``(GIB?`%F7F"6@'!BT0D
M,(G+B<:)QXM$)"C!Y@6)="0XBW0D.`^LUQN+5"0LB<$)_@'SP>$>,?\/K-`"
MB<V+3"0@B=X)Q0.,)!@!``")7"10BUPD:(EL)#B+5"0TB<@%H>O9;C'KBVPD
M8#'=B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0H"VPD*(M$)#`!Z8E,)&")
M3"0@B<'!X1X/K-`"B<N+5"1`"<,#E"0@`0``BVPD4(E<)$#'1"0L`````(G0
MBU0D)`6AZ]EN,UPD.#'=B?.)Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)
M\HE$)#`+;"0P`>G!XAX/K/L"B=6+E"0H`0``B4PD*`G=B4PD4(M<)$"+3"0X
MB6PD.('"H>O9;HG0BU0D*`'(,>N+;"1@BTPD*#'=BUPD+(GN`<;!X@6+1"0@
MB50D,(ML)#`/K-D;BU0D)(GS"<V)P0'KP>$>,?\/K-`"B<V+C"0P`0``B5PD
M8`G%BT0D0(G>B6PD,(ML)#B!P:'KV6X!R#-L)#"+5"0L,VPD4,=$)"0`````
MQT0D+`````")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)$`+;"1`BT0D*`'I
MB4PD((E,)%")P<'A'@^LT`*)RXN,)#@!``"+5"0D"<.+1"0XB=V)7"0XBUPD
M,('!H>O9;@'(,>N+;"1@,=V+G"1``0``B>D!P8M$)"#!X`6)1"0HBT0D((ML
M)"@/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)"B)3"1@"?6!PZ'K
MV6Z)[XML)#@!V(E\)$`Q_8GNBVPD4#'UB>D!P8M$)"B+5"0LB<:)QXM$)"#!
MY@6)="0PBW0D,`^LUQN+5"0DQT0D)``````)_@'Q,?^)SHE,)%")P<'A'@^L
MT`*)S8N,)$@!``"+5"0L"<6+1"0XB6PD,(ML)$"!P:'KV6X!R#-L)#`S;"1@
MB>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0X"VPD.(M$)"@!Z8E,)"")3"1@
MB<'!X1X/K-`"B<N+C"10`0``BU0D)`G#BT0D0(G=B5PD.(M<)#"!P:'KV6X!
MR#'KBVPD4#'=B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)1"1`"VPD
M0(N<)%@!``"+1"0PQT0D+``````!Z<'B'@^L_@*)U8E,)%")3"0H"?6!PZ'K
MV6Z+5"0LB>^+;"0X`=B)?"1`,?V)[HML)&`Q]8GI`<&+1"0HB<N)QHG'BT0D
M(,'F!8ET)#"+="0P#ZS7&XM4)"2)P<=$)"0`````"?X!\\'A'C'_#ZS0`HG-
MBXPD8`$``(M4)"P)Q8M$)#B)WHEL)#"+;"1`@<&AZ]ENB5PD8`'(,VPD,#-L
M)%")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)#@+;"0XBT0D*`'IB4PD4(E,
M)"")P<'A'@^LT`*)RXN,)&@!```)PXM$)$"+5"0DB5PD.(G=BUPD,('!H>O9
M;L=$)"P``````<@QZXML)&`QW8N<)'`!``")Z0'!BT0D(,'@!8E$)"B+1"0@
MBVPD*`^LT!N)\HE$)$`+;"1`BT0D,`'IP>(>#ZS^`HG5B4PD8(E,)"@)]8'#
MH>O9;HM4)"R)[XML)#@!V(E\)$`Q_8GNBVPD4#'UB>D!P8M$)"B)RXG&B<>+
M1"0@P>8%B70D,(MT)#`/K-<;BU0D)(G!"?X!\\'A'C'_#ZS0`HG-BXPD>`$`
M`(E<)%`)Q8M$)#B)WHEL)#"+;"1`@<&AZ]EN`<@S;"0P,VPD8(GI`<&)V,'@
M!8E$)"")V(ML)"`/K/@;BU0D+,=$)"0`````B40D.`ML)#B+1"0HQT0D+```
M```!Z8E,)"")3"1@B<'!X1X/K-`"B<N+E"2``0``"<.+1"1`B=V)7"0XBUPD
M,('"H>O9;@'0BU0D)#'KBVPD4#'=BYPDB`$``(GI`<&+1"0@P>`%B40D*(M$
M)""+;"0H#ZS0&XGRB40D0`ML)$"+1"0P`>G!XAX/K/X"B=6)3"0HB4PD4`GU
M@<.AZ]ENBU0D+(GOBVPD.`'8B7PD0#']B>Z+;"1@,?6)Z0'!BT0D*(G&B<?!
MY@6)="0PBW0D,`^LUQL)_@'Q,?^)3"1@BT0D((G.BU0D),=$)"0`````B<'!
MX1X/K-`"B<V+C"20`0``BU0D+`G%BT0D.,=$)"P`````B6PD,(ML)$"!P:'K
MV6X!R#-L)#`S;"10B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0X"VPD.(M$
M)"@!Z8E,)"")3"10B<'!X1X/K-`"B<N+C"28`0``BU0D)`G#BT0D0(G=B5PD
M.(M<)#"!P:'KV6X!R#'KBVPD8#'=B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/
MK-`;B?*)1"1`"VPD0`'IP>(>#ZS^`HG5B4PD8(E,)"@)]8N<)*`!``"+1"0P
MB>^+;"0XBU0D+(E\)$#'1"0T`````('#H>O9;@'8,?V)[HML)%`Q]8GIBVPD
M8`'!BT0D*(G+B<:)QXM$)"#!Y@6)="0PBW0D,`^LUQN+5"0DB<''1"0D````
M``G^`?/!X1X/K-`"B<Z+E"2H`0``BTPD0`G&BT0D.(E<)#")]XE<)%"!PJ'K
MV6X!T#'QBU0D-#'-B>D!P8M$)##!X`6)1"0@BT0D,(ML)"`/K-`;BU0D+(E$
M)#@+;"0XBT0D*`'IB4PD8(E,)"")P<'A'@^LT`*)SHN4)+`!``")^0G&BT0D
M0(E\)&B+;"10BWPD(('"H>O9;HET)#B+7"0X`=`Q\8M4)#0QS<=$)"P`````
MQT0D-`````")Z8ML)"0!P8GXP>`%B40D*(GX#ZSH&XML)"@)Q8M$)#`!Z8E,
M)%")3"0HB<>)P8M$)&`/K-<"P>$>B=J)S0G]B=^+7"0L">\AZHEL)$`A^(M\
M)"2)P0G1BU0D*(G.BXPDN`$``('!W+P;CXG(BTPD:`'(BTPD*`'&P>(%BT0D
M4(E4)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)#")7"1@#ZS^`L'A'HM<)$")
MSXM,)#@)]XGZB7PD4`G:(=")^B':B<4)U8N4),`!``")[H'"W+P;CXG0BU0D
M,`'(`<;!X@6)5"0@BTPD,(M<)#2+;"0@BWPD+(M$)&#'1"0D`````,=$)"P`
M````#ZS9&XGSBW0D*`G-`>N)\8E<)"")7"1H#ZS^`HM\)%#!X1Z)RXM,)$`)
M\XGZB5PD.`G:(=")^B':B<6+7"0D"=6+E"3(`0``B>Z!PMR\&X^)T(M4)"`!
MR(M,)"`!QHM$)&C!X@6)]XMT)#")5"0HBVPD*`^LV1N+7"0XBY0DT`$```G-
MB?$![\'A'HE\)"B)?"1@B<V+?"0TB=D/K/X""?4)Z2'KB6PD0"'(B<$)V8'"
MW+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,)"@!QL'B!8E4)#"+;"0P#ZS9&XGS
MBW0D((M\)"0)S8M$)&#'1"0T``````'KQT0D)`````")\8E<)&B)7"0P#ZS^
M`L'A'HM<)$")SXM,)#@)]XGZB7PD4`G:(=")^HM\)"PAVHG%BUPD-`G5BY0D
MV`$``(GN@<+<O!N/B="+5"0P`<B+3"0P`<:+1"1HP>(%B50D((ML)"`/K-D;
MB?.+="0H"<T!ZXGQB5PD((E<)&`/K/X"BWPD4,'A'HG+BTPD0`GSB?J)7"0X
M"=HAT(GZ(=J)Q8M<)"0)U8N4).`!``")[H'"W+P;CXG0BU0D(`'(BTPD(`'&
MP>(%B?>)5"0HBVPD*`^LV1L)S0'OB7PD:(E\)"B+="0PBWPD-(M<)#B+1"1@
MBY0DZ`$``,=$)"P`````B?''1"0T``````^L_@+!X1Z+?"0DQT0D)`````")
MS8G9"?4)Z2'KB6PD0"'(B<$)V8'"W+P;CXM<)"R)SHM,)%")T(M4)"@!R(M,
M)"@!QL'B!8M$)&B)5"0PBVPD,`^LV1N)\XMT)"`)S0'KB?&)7"0PB5PD8`^L
M_@+!X1Z+7"1`B<^+3"0X"?>)^HE\)%`)VB'0B?HAVHG%BUPD-`G5BY0D\`$`
M`(GN@<+<O!N/B="+5"0P`<B+3"0P`<;!X@6)5"0@BVPD(`^LV1N)\XMT)"@)
MS0'KB5PD:(E<)"")\8M\)"S!X1Z+1"1@B<N+3"1`QT0D+``````/K/X"BWPD
M4`GSB5PD.(GZ"=HAT(GZ(=J)Q8M<)"0)U8N4)/@!``")[H'"W+P;CXG0BU0D
M(`'(BTPD(`'&BT0D:,'B!8GWBW0D,(E4)"B+;"0H#ZS9&XM<)#B+E"0``@``
M"<V)\0'OP>$>B7PD*(E\)&")S8M\)#2)V<=$)#0`````#ZS^`HM\)"0)]0GI
M(>N);"1`(<B)P0G9@<+<O!N/BUPD+(G.BTPD4(G0BU0D*`'(BTPD*`'&P>(%
MB50D,(ML)#`/K-D;B?.+="0@"<T!ZXGQB5PD:(E<)#`/K/X"P>$>BUPD0(M$
M)&")SXM,)#C'1"0D``````GWB?J)?"10"=HAT(GZBWPD+"':B<6+7"0T"=6+
ME"0(`@``QT0D+`````")[H'"W+P;CXG0BU0D,`'(BTPD,`'&BT0D:,'B!8E4
M)""+;"0@#ZS9&XGSBW0D*`G-`>N)\8E<)"")7"1@#ZS^`HM\)%#!X1Z)RXM,
M)$`)\XGZB5PD.`G:(=")^B':B<6+7"0D"=6+E"00`@``B>Z!PMR\&X^)T(M4
M)"`!R(M,)"`!QHM$)&#!X@6)]XMT)#")5"0HBVPD*`^LV1N+7"0X"<V)\0'O
MP>$>B7PD:(E\)"B)S8M\)#2)V0^L_@()]0GI(>N);"1`(<B+E"08`@``BWPD
M)(G!QT0D-`````#'1"0D``````G9BUPD+(G.BTPD4('"W+P;CXG0BU0D*`'(
MBTPD*`'&P>(%BT0D:(E4)#"+;"0P#ZS9&XGSBW0D(`G-`>N)\8E<)#")7"1@
M#ZS^`L'A'HM<)$")SXM,)#@)]XGZB7PD4`G:(=")^HM\)"PAVHG%BUPD-`G5
MBY0D(`(``(GN@<+<O!N/B="+5"0P`<B+3"0P`<:+1"1@P>(%B50D((ML)"`/
MK-D;B?.+="0H"<T!ZXGQB5PD:(E<)"`/K/X"BWPD4,'A'HG+BTPD0`GSB?J)
M7"0X"=HAT(GZ(=J)Q0G5BY0D*`(``(GN@<+<O!N/B="+5"0@BUPD)`'(BTPD
M(,=$)"P``````<:+1"1HP>(%B?>+="0PB50D*(ML)"@/K-D;BUPD.(N4)#`"
M```)S8GQ`>_!X1Z)?"0HB7PD8(G-BWPD-(G9QT0D-``````/K/X"BWPD)`GU
M">DAZXEL)$`AR(G!"=F!PMR\&X^+7"0LB<Z+3"10B="+5"0H`<B+3"0H`<;!
MX@6+1"1@B50D,(ML)#`/K-D;B?.+="0@"<T!ZXGQB5PD,(E<)&@/K/X"P>$>
MBUPD0(G/BTPD.`GWB?J)?"10"=HAT(GZ(=J)Q0G5BY0D.`(``(GN@<+<O!N/
MB="+5"0P`<@!QL'B!8E4)""+3"0PBUPD-(ML)""+?"0LBT0D:,=$)"0`````
MQT0D+``````/K-D;B?.+="0H"<T!ZXGQB5PD((E<)&`/K/X"BWPD4,'A'HG+
MBTPD0`GSB?J)7"0X"=HAT(GZ(=J)Q8M<)"0)U8N4)$`"``")[H'"W+P;CXG0
MBU0D(`'(BTPD(`'&BT0D8,'B!8GWBW0D,(E4)"B+;"0H#ZS9&XM<)#B+E"1(
M`@``"<V)\0'OP>$>B7PD*(E\)&B)S8M\)#2)V0^L_@()]0GI(>N);"1`(<B)
MP0G9@<+<O!N/BUPD+(G.BTPD4(G0BU0D*`'(BTPD*`'&P>(%B50D,(ML)#`/
MK-D;B?.+="0@BWPD)`G-BT0D:,=$)#0``````>O'1"0D`````(GQB5PD,(E<
M)&`/K/X"P>$>BUPD0(G/BXPD5`(```GWB?J)?"10"=HAT(GZ,?\AVHG%"=6+
ME"10`@``B>Z!PMR\&X^#T0")T#';B<J+3"0X`<B+3"0P$=H!QHM<)#01UXM4
M)#`/K-D;P>(%B?.)_HE4)""+;"0@,=*+?"0L"<T!ZXML)%`1UHN4)%@"``")
M7"0@B70D;(MT)"B)7"1HBUPD)(GQ#ZS^`L'A'HGPB<Z+3"1`"<:!PM;!8LJ)
MT(M4)"")="0X`<@Q]8GIBVPD8#'-BTPD((GN`<;!X@6)5"0HBVPD*`^LV1N+
M?"0PB?.+E"1@`@``"<W'1"0L``````'KBVPD-,=$)#0`````B?F)7"1@B5PD
M*,'A'HM<)&@/K.\"B<V+3"10"?V!PM;!8LJ+?"0DB="+5"0HB6PD0`'(BTPD
M.#'I,<N+3"0HB=Z+7"0L`<;!X@6+1"0XB50D,(ML)#`/K-D;B?.+="0@BU0D
M-`G-`>N+;"1@B?&)7"0PB5PD4,'A'HM<)$`/K/X"B<^+C"1H`@``"?>)?"0X
M@<'6P6+*`<@Q^S'=B>D!P8M$)#")RXG&#ZS0&\'F!8E$)""+;"0@"?4!ZXE<
M)&")7"0@QT0D)`````"+="0HBWPD+(ML)#B+1"1`BU0D)(GQQT0D+``````/
MK/X"P>$>"?&)SHN,)'`"``")="1`@<'6P6+*`<@Q]8GNBVPD4#'UB>D!P8M$
M)"")Q\'G!8E\)"B)QXMT)"@/K-<;BT0D,(M4)#0)_@'Q,?^)SHE,)%")P<'A
M'@^LT`*)S8N4)'@"```)Q8M$)#B);"0PBVPD0('"UL%BR@'0,VPD,(M4)"0S
M;"1@B>D!P8GPP>`%B40D*(GPBVPD*`^L^!N)1"0X"VPD.(M$)"`!Z8E,)&")
M3"0HB<'!X1X/K-`"B<N+C"2``@``"<.+1"1`B=V)7"0XBUPD,('!UL%BRHM4
M)"S'1"0D``````'(,>N+;"10,=V+G"2(`@``B>D!P8M$)"C!X`6)1"0@BT0D
M*(ML)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)%")3"0@"?6!
MP];!8LJ+5"0DB>^+;"0X`=B)?"1`,?V)[HML)&`Q]8GI`<&+1"0@B<N)QHG'
MBT0D*,'F!8ET)#"+="0P#ZS7&XM4)"R)P0G^`?/!X1XQ_P^LT`*)S8N,))`"
M``")7"1@"<6+1"0XB=Z);"0PBVPD0('!UL%BR@'(,VPD,#-L)%")Z0'!B=C!
MX`6)1"0HB=@/K/@;B40D.(ML)"@+;"0XBT0D((M4)"3'1"0L`````,=$)"0`
M`````>F)3"10B4PD*(G!P>$>#ZS0`HG+BXPDF`(``(M4)"P)PXM$)$")W8E<
M)#B+7"0P@<'6P6+*`<@QZXML)&`QW8N<)*`"``")Z0'!BT0D*,'@!8E$)""+
M1"0HBVPD(`^LT!N)\HE$)$`+;"1`BT0D,`'IP>(>#ZS^`HG5B4PD((E,)&`)
M]8'#UL%BRHM4)"2)[XML)#@!V(E\)$`Q_8GNBVPD4#'UB>D!P8M$)"")RXG&
MB<?!Y@6)="0PBW0D,`^LUQL)_@'S,?^)7"10BT0D*(G>BU0D+,=$)"P`````
MB<'!X1X/K-`"B<V+C"2H`@``BU0D)`G%BT0D.,=$)"0`````B6PD,(ML)$"!
MP=;!8LH!R#-L)#`S;"1@B>D!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"0X"VPD
M.(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<N+E"2P`@``"<.+1"1`B=V)7"0X
MBUPD,('"UL%BR@'0BU0D+#'KBVPD4#'=B>D!P8M$)"C!X`6)1"0@BT0D*(ML
M)"`/K-`;B?*)1"1`"VPD0`'IP>(>#ZS^`HG5B4PD4(E,)"`)]8N<)+@"``"+
M1"0PB>^+;"0XBU0D)(E\)$"!P];!8LH!V#']B>Z+;"1@,?6)Z0'!BT0D((G+
MB<:)QXM$)"C!Y@6)="0PBW0D,`^LUQN+5"0LB<''1"0L``````G^`?/!X1XQ
M_P^LT`*)S8N,),`"``"+5"0D"<6+1"0XB5PD8(EL)#"+;"1`B=Z!P=;!8LH!
MR#-L)#`S;"10B>D!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"0X"VPD.(M$)"`!
MZ8E,)%")3"0HB<'!X1X/K-`"B<N+E"3(`@``"<.+1"1`B=V)7"0XBUPD,('"
MUL%BR@'0,>N+;"1@,=V)Z0'!BT0D*(M4)"R+G"30`@``QT0D)`````#!X`6)
M1"0@BT0D*(ML)"`/K-`;B?*)1"1`"VPD0(M$)#`!Z<'B'@^L_@*)U8E,)&"+
M5"0D"?6!P];!8LJ)3"0@B>^+;"0X`=B)?"1`,?V)UXGNBVPD4#'UB>D!P8M$
M)"")RP^DQP6)QL'F!8E\)#2)QXET)#"+1"0HBW0D,`^LUQN+5"0LB<$)_@'S
MP>$>,?\/K-`"B<V+C"38`@``B=X)Q8E<)%"+1"0XBYPDW`(``(EL)#"!P=;!
M8LJ+;"1`@],`,=(!R!':,VPD,#';,VPD8(GI`<&)\!'3P>`%,=*)1"0HB?`/
MK/@;B40D.(ML)"@+;"0XBT0D(,=$)"P``````>D1TXM4)"2)3"0HB4PD8(G!
MB5PD9,'A'L=$)"0`````#ZS0`HG+BY0DX`(```G#BT0D0(G=B5PD.(M<)#"!
MPM;!8LH!T(M4)"PQZXML)%`QW8N<).@"``")Z0'!BT0D*,'@!8E$)""+1"0H
MBVPD(`^LT!N)\HE$)$`+;"1`BT0D,`'IP>(>#ZS^`HG5B4PD((M4)"0)]8'#
MUL%BRHE,)$")[XML)#@!V(E\)#`Q_8G7B>Z+;"1@,?6)Z0'!BT0D(`^DQP6)
MQL'F!8E\)%2)QXET)%"+="10#ZS7&XM4)"P)_HGP`<@Q_XG&BT0D*(G!P>$>
M#ZS0`HG-BU0D)`G%BT0D((EL)%")TXG!#Z3+'L'A'HE,)"")T8G"#ZS*`L'I
M`HM$)#B)7"0DB4PD+(N,)/`"``"+7"0PB50D*(GZ@<'6P6+*`<@QZXML)$`Q
MW8GI`<&)\,'@!8E$)#B)\(ML)#@/K/@;#Z3R!8E$)$`+;"1`B50D/(GZP>H;
MB50D1(M4)$R)Z(ML)"`!R(G!BT0D&`-,)!#'0@0`````QT(,``````'P"VPD
M*(E""(D*B>@#!"2)0A"+1"10`T0D",="%`````#'0AP`````QT(D`````(E"
M&(M$)#`#1"18B4(@BX0D_`(``&4S!10```!U"X'$#`,``%M>7UW#Z%@A``"0
MC;0F`````%575E/H)]G__X'#8Y$``(/L'(7`#X2K````BXL4`0``BPF%R8E,
M)`@/A)<````/M@B$R71K@/D]=&:)QH/&`0^V#H3)=`6`^3UU\2G&BTPD"(LI
MA>UT-HE4)`R)1"0$B<^-M"8`````@^P$5O]T)`Q5Z/K5__^#Q!"%P'4'@'PU
M`#UT)(/'!(LOA>UUVX/$'(GH6UY?7<.)]HV\)P`````Q]NNIC70F`(GZ*U0D
M"(M$)`R-;#4!P?H"B1"#Q!R)Z%M>7UW#,>WKQ(VT)@````!75HG&4^B"V?__
M@<*2D```@^P0B[H4`0``C5PD"&6A%````(E$)`PQP(G:B?#H_O[__X7`=#N-
M=@"-O"<`````BU0D"(L'C020BU`$A=*)$'37C;8`````@\`$BU`$A=*)$'7T
MB=J)\.C#_O__A<!USXM$)`QE,P44````=0>#Q!!;7E_#Z/8?``"-M@````!5
M5XG%5E.)UNC#U___@</_CP``@^PX9:$4````B40D*#'`,<"`.CT/E,`!QE;H
M+M3__X/$$(D$)(GHC50D&.A=_O__A<`/A`T!``"#[`R)QU#H"M3__X/$$#D$
M)`^&W@```(M$)!B-#(4`````BX,4`0``B40D!`^V10"$P`^$G`$``#P]#X24
M`0``B>CK!I"`^CUT"H/``0^V$(32=?$IZ(M4)`2#[`R+.@'/BTPD#(U$"`)0
MZ&[3__^#Q!"%P(D'#X1K`0``BU0D!(U-`8L"BU0D&(L4D`^V10`\/8@"=".$
MP'4/ZQV)]HV\)P`````\/700@\$!#[9!_X/"`83`B`)U[,8"/3'`C;0F````
M``^V#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/A0H!``"#Q"Q;7E]=PXVV
M`````(/&`0^V1O^#QP&$P(A'_W7OZ\R0C70F`(N#%`$``(L0B40D!(LZA?\/
MA+@````QP.L(C;8`````B?B->`&+#+J%R77TC02%#````(N+=!$``(7)=#N#
M[`A04NB!TO__BTPD%(/$$(7`B0$/A((```"-#+T`````B40D"(M$)`C'1+@$
M`````(E\)!CII_[__XE4)`B#[`S'@W01```!````4.A!TO__@\00A<!T1(T,
MO0````"#[`11BU0D$(E,)!12B40D%%#H=-'__XM,)!2+1"08@\00B0&+3"0,
MZYPQP.E[_O__N`@````Q_^E9____N/_____IY?[__^BO'0``ZPV0D)"0D)"0
MD)"0D)"055=64XG&Z'75__^!P[&-``"![(P```!EH10```")1"1\,<"%]G0%
M@#X`=22+1"1\93,%%`````^%1`$``('$C````%M>7UW#D(VT)@````"#[`Q6
MZ)?2__^#Q!"%P(G'=,J-@Q20__^)1"0(C40D'(E$)`R-="8`@^P,5^@OTO__
M@\00A<")Q0^$R@````^V51.X+@```(G!*=%U&P^V512%TG33*=`/A)L```#W
MV(7`=,7K!XUV`(7)=+R#[`Q6Z$O1__^-51.)1"04B10DB50D$.@XT?__BTPD
M%(U$`0*)!"3H\-#__XG%6%J+5"0(4E;_="08:O]J`57H^-'__X/$'/]T)!!5
M:@/HN='__X/$$(/X_W00BT0D+"4`\```/0!```!T48/L#%7H2-#__X/$$(/L
M#%7H_,___X/$$.DT____C70F``^V117I7O___XVT)@````"#[`Q7Z(?1__^)
M-"3HY\___X/$$.F[_O__C;0F`````(GHZ('^___KLN@:'```C78`C;PG````
M`%=6B<=3Z.;3__^!PR*,``"#[`R+LTP```#_-N@@T?__@\0,!3@!``!05VH#
MZ!?1__^#Q!"%P'0(6S'`7E_#9I"#[`S_-NCVT/__BX!(`0``@\00)0#P```]
M`$```'0?@^P,_S;HU]#__XN`2`$``(/$$"4`\```/0"@``!UNH/L"&H"5^AO
MT/__@\00A<`/E,!;#[;`7E_#D(VT)@````!55XG'5E/H1=/__X'#@8L``('L
M,!```&6A%````(F$)"`0```QP(E4)!!H_P\``(V#&I#__XUT)"164.@8S___
M@\00A<!^88UH_X!\+!P`=$^)Q8/L!%5J+U;HR<___X/$$(7`=$*+@TP```"#
M[`S_,.@JT/__55974.CQS___@\0@BX0D'!```&4S!10```!U.8'$+!```%M>
M7UW#C78`A>UUKXUT)@"+@TP```"#[`S_,.CHS___@\0,_W0D$%=0Z)K.__^#
MQ!#KM^B@&@``4^AZTO__@<.VB@``@^P4BX-,````_S#HM,___XV3-)+__U*-
MDRF0____LS0```!24.@"S___@\0H6\.0C70F`%93Z#G2__^!PW6*``"#[!"+
MLTP```#_-NASS___B00DZ)O___]8_S;H8\___UJ-D^F1__]9:@!24HV3-(O_
M_U*-DT60__]24.CSSO__@\0D6U[#C;8`````C;PG`````%575E/HU]'__X'#
M$XH``('L'"```&6A%````(F$)`P@```QP.CWS?__C9,ED/__@^P(4E"-@UJ0
M__]0:`$0``!J`8UT)"96Z`S/__^#Q""%P'AM@^P$:``0``"-O"03$```5U;H
M?\W__X/$$(7`B<5X3HU``8/L#%#HNLW__X/$$(7`B<9T$H/L!%574.@.S?__
MQ@0N`(/$$(N,)`P@``!E,PT4````B?!U&8'$'"```%M>7UW#C78`C;PG````
M`#'VZ]7H-QD``(VT)@````#I*____XUT)@"-O"<`````55=64^CWT/__@<,S
MB0``@>PL$```BX0D0!```(U4)!B+M"1$$```B00DB<=EH10```")A"0<$```
M,<"-@VB0___HBO?__X/L"(G%:B]7Z"W-__^#Q!"%P'0QBSPDC8-QD/__B?KH
MQOC__XGXBY0D'!```&4S%10````/A9@!``"!Q"P0``!;7E]=PX/L#/]T)`SH
M^<S__UI9B<>-@WZ0__^)1"0,4%;H9,W__XG&C4<!@\00B40D"(N#3````(E$
M)`R-M@````"%]G2.@#X`#X3;````A>UT%8/L"%95Z+7+__^#Q!"%P`^$HP``
M`(/L#%;HF<S__X/$$(!\!O\O=16-M"8`````@^@!@'P&_R_&!`8`=/(#1"0(
M/?\/```/CS7___^-@X"0__^#[`3_="0$4(V#I)'__U90:``0``!J`8UT)#A6
MZ"S-__^#Q!2+?"08_S?H]LS__X/$#`4X`0``4%9J`^C=S/__@\00A<!U'X/L
M#/\WZ-3,__^+@$@!``"#Q!`E`/```#T`@```=%>#[`C_="0,:@#H<<S__X/$
M$(G&Z1____^-M"8`````A>UT)(V#9I#__[D"````B>Z)Q_.F=,J)QK@!````
MZ4/___^0C70F`(VS9I#__[@!````Z2[___^#[`AJ`5;H%<S__X/$$(7`=9>-
M@W&0__^)\N@I]___@^P,5NBXR___@\00Z53^___H`Q<``(UV`(M$)`0/M@B$
MR705C5`!9I"`^2\/M@H/1,*#P@&$R77P\\.-M"8`````C;PG`````%93Z*G.
M__^!P^6&``"#[!2+="0@A?9T4`^V%H32=$F(5"0/@^P,5N@4R___C40&_X/$
M$`^V5"0/.<9R"^L>9I"#Z`$YQG09@#@O=/3K!V:0@#@O=$"#Z`$YQG+T.<9U
M-8#Z+W5SC78`@^P,:@+HELK__X/$$(7`=%>Z+@```&:)$(/$%%M>PXGVC;PG
M`````(`X+W4'@^@!.<9R]"GPC5`"@?H`$```=R>#P`%H`!```%!6C;-T`0``
M5NCARO__@\00B?"#Q!1;7L.-M@````"#Q!0QP%M>PXV#@)#__X/L#%#HD<K_
M_X/$$.N5C70F`%=64^BXS?__@</TA0``@^PP9:$4````B40D+#'`BX,0DO__
MC70D!(E$)`J+@Q22__^)1"0.BX,8DO__B40D$HN#')+__XE$)!:+@R"2__^)
M1"0:BX,DDO__B40D'HN#*)+__XE$)"*+@RR2__^)1"0F#[>#,)+__V:)1"0J
MC8."D/__Z-CT__^-@XN0___HS?3__XV#DY#__^C"]/__C8.<D/__Z+?T__^-
M@Z.0___HK/3__XV#LY#__^BA]/__C8-HD/__Z);T__^-@[^0___HB_3__XV#
MR9#__^B`]/__C8/3D/__Z'7T__^-@W&0___H:O3__XV#W9#__^A?]/__C8/F
MD/__Z%3T__^-@_&0__^)\NAW\___A<!T#8G"C8/)D/__Z,;T__^-@P*1__^)
M\NA9\___A<!T#8G"C8,4D?__Z*CT__^-@Q^1__^)\N@[\___A<!T-XG"C8-H
MD/__Z(KT__^-DTN1__^-@Z.0___H>?3__XM$)"QE,P44````=5"#Q#!;7E_#
MD(UT)@"-@R^1__^)\NCS\O__A<!T#XG"C8._D/__Z$+T___KMHUT)!N-NT"1
M__^Y"@```/.F=:.-5"0EC8._D/__Z![T___KDN@'%```C;0F`````%/HVLO_
M_X'#%H0``(/L&&6A%````(E$)`PQP(N#/`$``(/X_W0:BTPD#&4S#10```!U
M08/$&%O#D(VT)@````"-5"0(C8._D/__Z&'R__^%P'0=#[80@/HP#Y7`A-(/
ME<(AT`^VP(F#/`$``.NX9I`QP.OOZ(<3``"-M"8`````4^A:R___@<.6@P``
M@^P(Z#S'__^#[`Q0Z.O&__^#Q!"%P'0,BP"#Q`A;PY"-="8`,<#K\HVV````
M`(V_`````%575E/H%\O__X'#4X,``(/L7(M$)'"-NU>1__^-LTV1___'1"1(
M`````(UL)#")?"0PB70D-(E$)`AEH10```")1"1,,<"-@UJ1__^)1"0XC8-0
MD?__B40D/(V#59'__XE$)$"-@V>1__^)1"1$C40D+(E$)`R-@WZ0__^)1"04
MC8.DD?__B40D&.LHC70F`(/L"/]T)!!0B40D(.@/QO__@\00A<!T2(/%!(7V
M="N)]XMU!(M4)`R)^.@Q\?__A<!T!8`X`'7(BU0D"(GX@\4$Z'KR__^%]G75
MBT0D3&4S!10```!U;H/$7%M>7UW#D(/L#/]T)!3HM,;__XM,)"")1"0LB0PD
MB4PD(.B@QO__BU0D+(U$`@*)!"3H6,;__X/$#(M,)!11_W0D'/]T)!3_="0H
M:O]J`5")1"0PZ%;'__^#Q""+5"00B?CH`/+__^E3____Z.81``"-M@````!5
M5U93Z"(1``"!Q?.!``"![#R!``"+A"10@0``C50D/(V=<I'__\=$)$@`````
MQT0D;`````")7"1,QT0D5`````")1"0<B50D%&6A%````(F$)"R!```QP(V%
M?I'__XE$)$"-A6:0__^)1"1$C844D?__B40D#(E$)%B-A0V1__^)1"1<C86#
MD?__B40D8(V%*I'__XE$)&2-A8N1__^)1"1HC86/D?__B40D4(V%:)#__^C8
M[___A<!T"8`X``^%>P0``.B6_?__A<")Q@^$DP0``(/L#(GK5NAQQ?__C40`
M`8D$).@MQ?__B40D((/$$(`^`'0VC868D?__BWPD$(D$)(UT)@`/M@:#[`R)
MZX/&`5#_="00:O]J`5>#QP+H$\;__X/$((`^`'7;C5PD6(M$)`R+?"04ZPZ0
MC70F`(/#!(L#A<!T+XGZZ$#O__^%P(G&=.J`.`!TY>AP]/__A<!TW(/L#(GK
M5N@9Q?__@\00A<")QW5"BUPD0#'VZPN#Q@&+7+1`A=MT+8`[`'0HB=CH.?3_
M_X7`=.6#[`Q3B>OHXL3__X/$$(7`=-.)Q^L)C;0F`````#'_@^P,B>M7Z(O$
M__^#Q!"+3"00BQF#P02-D__^_O[WTR':@>*`@("`=.F)T\'K$/?"@(````]$
MTXU9`@]$RXG3`-.)ZX/9`RM,)!"#[`R-M`$$!```5N@$Q/__B40D'(G!C86=
MD?___W0D(%"-A8"0__^)1"0H4(V%HI'__U>)SU!J_VH!4>CTQ/__@\0H:,`!
M``!7Z"[$__^#Q!"#^/\/A)(```"+O4P```"#[`R)Z_\WZ*#$__^#Q`P%.`$`
M`%#_="04:@/HE,3__XE$)#"#Q!"%P`^$I0```(/L#(GK_W0D&(M$)"S_,(V%
M?)+__U"+A2````!J`?\PZ$#$__^#Q"#'1"08`````(N,)"R!``!E,PT4````
MBT0D&`^%20H``('$/($``%M>7UW#C78`C;PG`````.B;P___BP"#^!$/A%[_
M__^#[`A0_W0D&(M$)"S_,(V%0)+__U"+A2````!J`?\PZ-3#__^#Q"#'1"08
M`````.N2C;0F`````(/L#/\WZ,[#__^+@$@!``"#Q!`E`/```#T`0```#X4X
M____@^P,_S?HJ\/__XN`4`$``(E$)!#H/,+__X/$$#D$)`^%$____X/L#/\W
MZ(;#__^+@$@!``"#Q!`E_P$``#W``0``#X7P_O__@^P,B>M6Z&K"__^+5"0D
MB40D*(V%4)'__^C/[/__@\00A<`/A`0"``"#[`R)ZU#HL<+__UI94(M$)"C_
M,.C;]/__B40D$(/$$(7`#X3<`0``@^P,B>N+?"0,5^A-PO__@\00@_@#?BV-
M=`?\B?N-O:N1__^Y!0```/.F=1B#^`0/A*8'``"`?`/[+P^$FP<``(UT)@#H
MH_G__X7`=1^#[`B)ZVH`_W0D#.@/PO__B40D+(/$$(7`#X5^`0``C95+D?__
MC;7ID?__C86_D/__B>N-O=*1___H<>W__^A\P?__5E"-A<21____="08_W0D
M&%!J_VH!_W0D-.B6PO__@\0@B30DB7PD%(MT)""+?"08ZT"-=@"-O"<`````
MZ,O!__^#.!%U1(GK@\8!Z"S!__^#[`S_="0,5E#_="0H_W0D*/]T)#1J_VH!
M5^A%PO__@\0P@^P(B>MHP`$``%?H>L'__X/$$(/X_W2R@^P,B>O_="08Z%S`
M__^+?"0HC85HD/__B?KHP^S__XD\).AK^?__@\00Z8;]__^-=@"#[`R)ZU")
M1"00Z%'Y__^+1"00B00DZ"W!__^)1"0H@\00Z5S]__^_`0```(G8BW0D%.L/
MC70F`(M$O$R#QP&%P'0IB?+H!NO__X7`=.J`.`!TY8/L#(GK4.CJP/__@\00
MA<!TTXG&Z2C[__^#[`R)ZXVU=Y'__VH-Z%K`__^)1"0@@\00Z2W[__^-M@``
M``"+1"0<BP")!"3I%O[__VH":O]J[HM\)"A7Z`K`__^#Q`QJ!HV$)#0!``")
M1"0<4%?H6[___X/$$("\)"P!````=0Z`O"0M`0``0P^$;P8``&H`:@")ZVH`
M_W0D*.C'O___QX0D@`````$C16?'A"2$`````````,>$)(@```")J\WOQX0D
MC`````````#'A"20````_MRZF,>$))0`````````QX0DF````'94,A#'A"2<
M`````````,>$)*````#PX=+#QX0DI`````````#'A"2H`````````,>$)*P`
M````````QX0DL`````````#'A"2T`````````,>$)/@`````````@\00C40D
M<(DL)(E$)"R-A"2H````B40D()"#[`1H`(```/]T)!S_="0HBUPD$.A7OO__
M@\00A<")Q@^."P(``(N,))@```"+G"2<````B?")]<'@`XGWP?T?`<B#^P`/
MA\T!```YP0^'Q0$``(N,)*````"+G"2D````B80DF````(GXB>H/K.@=P>H=
MQX0DG``````````!R(F$)*````"+A"3H````$=J)E"2D````A<`/A&D!``"_
M0````"G'.?X/3OX#1"0@@^P$5_]T)!Q0BUPD$.C/O?__BX0D^`````'XB80D
M^````(/$$(/X0`^%(____XM$)"PI_@-\)!3H%,/__XUT)@"#_C\/CN@```"-
M1L"+;"0LB?Z)1"0HP>@&C5@!B40D),'C!@'[C78`BP:#QD")A"2H````BT;$
MB80DK````(M&R(F$)+````"+1LR)A"2T````BT;0B80DN````(M&U(F$)+P`
M``"+1MB)A"3`````BT;<B80DQ````(M&X(F$),@```"+1N2)A"3,````BT;H
MB80DT````(M&[(F$)-0```"+1O")A"38````BT;TB80DW````(M&^(F$).``
M``"+1OR)A"3D````B>CH/\+__SGS#X5/____BTPD*(G(@^#`C7P'0(M$)"3!
MX`8IP8G.:D165_]T)"R+7"00Z$:]__^)M"3X````@\00Z?_]__^-M"8`````
MBWPD%.G?_O__C;0F`````(N,)*````"+G"2D````@\$!@],`Z3#^__^++"2#
M[`S_="0HB>OH[KW__XN$)+````"+G"2H````B[0DK````(N4)+0```")1"00
MB=@/K/`#B50D%(/@/XU0`<:$!+@```"`@\00@_HX#X^D`@``N#@````IT`-4
M)""#^`0/@\D"``"%P'0+J`+&`@`/A7\#``"+5"0$BP0DB)PDYP````^LT!B+
M5"0$B(0DX````(L$)`^LT!"+5"0$B(0DX0```(L$)`^LT`B(A"3B````#[8$
M)(B$).,```")V`^L\!B(A"3D````B=@/K/`0B(0DY0```(G8#ZSP"(B$).8`
M``"+1"0LZ-_`__^+="1PBWPD=(GQ#ZSY&(B,).\````/ML&)\0^L^1"(C"3P
M````B?$/K/D(BWPD?(B,)/$```")\8MT)'B(C"3R````B?$/K/D8B(PD\P``
M`(GQ#ZSY$(B,)/0```")\0^L^0B+O"2$````B(PD]0```(GQB[0D@````(B,
M)/8```")\0^L^1B(C"3W````B?$/K/D0B(PD^````(GQ#ZSY"(N\)(P```"(
MC"3Y````B?&+M"2(````B(PD^@```(GQ#ZSY&(B,)/L```")\0^L^1"(C"3\
M````B?$/K/D(B[PDE````(B,)/T```")\8NT))````"(C"3^````B?$/K/D8
MB(PD_P```(GQ#ZSY$(B,)``!``")\0^L^0B-O"0K`0``B(PD`0$``(GQC;0D
M\````(B,)`(!``"-C"0#`0``B4PD'(G*C8V8D?__B0PDB7PD%(GWB=;I!P``
M`)`/M@>#QP&#[`R)ZU#_="00:O]J`5:#Q@+HJ[O__X/$(#ET)!1UVHV%Z9'_
M_\:$)"L!````B>M0C86UD?___W0D(/]T)!C_="084&K_:@'_="0TZ'&[__^#
MQ"#I/_G__XM$)!R+4`2%T@^$6OC__X/L#(GK4HE4)"3H8[K__X/$$(/X`P^&
M/_C__XM4)!2-O;"1__^Y!0```(UT`OSSI@]%%"2)%"3I'OC__XM,)""X0```
M``'1*=")PG0-,<#&!`$`@\`!.=!R]8M$)"SHK[[__XM\)""Y#@```#'`\ZOI
M1OW__XU*!,<"`````,=$`OP`````@^'\*<H!PH/B_(/Z!`^"(OW__X/B_#'`
MQP0!`````(/`!#G0<O+I"OW__X"\)"X!``!!#X6#^?__@+PD+P$``$,/A77Y
M__^`O"0P`0``2`^%9_G__X"\)#$!``!%#X59^?__:@)J_VK&BW0D*%;H(;G_
M_X/$#&HIBWPD'%=6Z'FX__^-A>F1__]0C86UD?__5_]T)"C_="0H4&K_:@'_
M="1$Z"VZ__^#Q##I^_?__Y"-="8`,<EFB4P"_NEU_/__Z+<$``"-M"8`````
M55=64^B'O/__@</#=```@^PXBZM,````9:$4````B40D*#'`_W4`Z+2Y__]?
M_W4`B<;HJ;G__P^V0&2(1F6-1"0HB40D'(G"C8.CD/__Z`WC__^#Q!"%P'0)
M@#@Q#X1]`@``Z&CN__^#[`S_=0#H;;G__XV3XY'__VH+:@%24.ALN/__@\0@
MA<`/A+(```"+0`R#NWP1```!BT`8B40D!`^.FP```#'_O@$```#K+9"+0@R#
M[`A0BX-X$0``_S2PZ&.W__^#Q!"%P'5DBX-\$0``@\8!@\<!.?!^6H/L#/]U
M`.CYN/__:@!7_W0D'%#HM+C__X/$((7`=#6+$(M"""4`!"``/0`$``!TI(E4
M)`B#[`S_=0#HQ;C__VH":@"+5"0@4E#H?K?__X/$(.N$D(N#?!$``(U0_SGZ
M#X1?`0``@^P,_W4`Z)2X__^-D^B1__]J`VH!4E#HD[?__X/$((7`B<9T,XM`
M#(/L#(LX_W4`Z&JX__^-D^J1__^#Q`Q25U#H&;?__XM&#(/$$(LP]D8*0`^%
ML`$``(/L#/]U`.@\N/__C9/OD/__:@-J`5)0Z#NW__^#Q""%P(G&=#>+5"0,
MC8-QD/__Z)/A__^%P(G'#X1)`0``BT8,@^P,BS#_=0#H^;?__X/$#%=64.BN
MMO__@\00@^P,_W4`Z."W__^-D^^1__^#Q`QJ`5)0Z":W__^)QEC_=0#HP[?_
M_XV3!)+__X/$#%)64.ARMO__6O]U`.BIM___BU0D',9`90"-@VB0___H%N'_
M_X/$$(7`B<:)@X`1```/A),```"#[`AHP`$``%;HY;;__XU0`8/$$(/Z`78)
M@_@1#X7K````BT0D'&4S!10````/A=4```"#Q"Q;7E]=PY"-M"8`````@_@!
M#XZ8_O__BWPD!+X!````C;8`````@^P,_W4`@\8!Z!JW__]:65=0Z(FU__^#
MQ!`YLWP1``!_WNEB_O__D(!X`0`/A'[]___I=/W__Y"#[`S_LW@1``#HTN__
M_X/$$(7`B<:)@X`1```/A4S___^-@]"2__^#[`Q0Z""V__^+@W@1``"#[`R+
M.(M&#(LP_W4`Z*BV__^)^HGPZ/_E__^#Q!#IK/[__X/L#/]U`.B,MO__65]6
M4.@;MO__@\00Z33^___H1@$``%"+@W@1``!6_S"-@_22__]0Z,"U__]75E.+
M="00Z`2Y__^!PT!Q``"#[`Q6Z$7J__\/M@B#Q!"$R71(C5`!B<>-M@````"`
M^2\/M@H/1/J#P@&$R77PZ.OL__^%]G0@A<!T'(`^`'07C8.=D?__@^P(4%?H
M/K3__X/$$#GX=`A;7E_#B<?KSUN)\%Y?Z17C__^++"3#D%/HBKC__X'#QG``
M`(/L"(V#.`$``(7`=!^+`%#_="0<_W0D'/]T)!SHD[3__X/$&%O#C;8`````
M,<#KWV:09I!55U93Z$>X__^!PX-P``"#[`R+;"0@C;/P_O__Z(NS__^-@^S^
M__\IQL'^`H7V="4Q_XVV`````(/L!/]T)"S_="0L5?^4N^S^__^#QP&#Q!`Y
M_G7C@\0,6UY?7<.-=@#SPV:09I!FD&:09I!FD&:04^C:M___@<,6<```@^P(
MZ+2S__]3@^P(Z,.W__^!P_]O``"#Q`A;PP,````!``(`)7,O)7,`+W!R;V,O
M<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.
M04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'
M`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],
M24)205)97U!!5$@`4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$
M25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`
M)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M`$%21U8`&`!P97)L`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#,U`"UE`"TM
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN
M8P```"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`````979A;"`G97AE8R`O=7-R+V)I
M;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD
M("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R
M(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B([
M"F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS
M>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?
M05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@
M*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD
M7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0[
M"F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA
M;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I
M"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?
M1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R
M;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F
M9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@
M=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L
M(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@
M/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@
M,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M
M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I
M(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W
M-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D
M;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M"FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N
M86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D
M;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2
M*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@
M97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D
M("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H
M(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC
M;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M
M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F
M:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H
M*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C
M*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A
M<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI
M;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@
M)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6
M>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3
M*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@`!&P,[Z````!P```"0<O__!`$``)!T__^<#0``
M0'C__R@!``#@G?__;`$``+">___0`0``0)___P@"``"0H?__B`(``""C__]`
M`P``P*/__[`#``"0I/__3`0``-"D__]\!```,*7__\@$````IO__7`4``!"F
M__]P!0``,*C__VP&``!@J/__@`8``%"I___T!@``,*O__RP'``"PJ___4`<`
M`/"K__]\!P``4*W___`'``"`NO__V`L```"^__],#0``>[[__^0-``"`OO__
M^`T``,"^__\L#@``(+___W@.```PO___C`X``!0``````````7I2``%\"`$;
M#`0$B`$``"`````<````A''__Q``````#@A&#@Q*#PMT!'@`/QH[*C(D(D``
M``!`````$'?__Y@E````00X(A0)!#@R'`T0.$(8$00X4@P5&#J`&`X$E"@X4
M0<,.$$'&#@Q!QPX(0<4.!$$+````8````(0```!LG/__R0````!!#@B%`D$.
M#(<#00X0A@1!#A2#!4X.,`)9#C1!#CA$#CQ!#D!(#C!7"@X40\,.$$'&#@Q!
MQPX(0<4.!$H+7@H.%$/##A!!Q@X,0<<."$'%#@1!"S0```#H````V)S__XH`
M````00X(AP)!#@R&`T,.$(,$3@X@`FX*#A!!PPX,0<8."$''#@1!"P``?```
M`"`!```PG?__00(```!!#@B%`D$.#(<#0PX0A@1!#A2#!5`.3%<.4$@.0%D.
M3$,.4$@.0`)/#DQ-#E!(#D`">`H.%$'##A!!Q@X,0<<."$'%#@1'"P)8#DA!
M#DQ!#E!,#D!Q#DQ+#E!(#D!.#D1!#DA)#DQ%#E!0#D````"T````H`$```"?
M__^&`0```$$."(4"00X,AP-!#A"&!$$.%(,%4PZ@`6P*#A1!PPX00<8.#$''
M#@A!Q0X$20M##JP!00ZP`4@.H`%?#JP!00ZP`4@.H`%[#JP!00ZP`6L.K`%!
M#J@!10ZL`4$.L`%$#K0!0@ZX`4(.O`%!#L`!2`ZD`40.J`%!#JP!0@ZP`4@.
MH`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%<#JP!00ZP`5`.H`$`;````%@"
M``#8G___F`````!!#@B'`D$.#(8#0PX0@P1.#AQ(#B!(#A1&#AA!#AQ"#B!(
M#A!%"L,.#$/&#@A!QPX$0PM##AQ"#B!.#A!/#AQ"#B!.#A!/#AA"#AQ!#B!(
M#A!&PPX,1,8."$''#@0``)@```#(`@``"*#__]``````00X(A0)!#@R'`T,.
M$(8$00X4@P51#L0@6`[(($L.S"!!#M`@2`[`(%,.Q"!!#L@@0@[,($$.T"!(
M#L`@30[,($(.T"!&#M0@00[8($$.W"!!#N`@2`[`(%8*#A1!PPX00<8.#$''
M#@A!Q0X$1`M1#LP@0@[0($@.Q"!$#L@@00[,($$.T"!(#L`@`"P```!D`P``
M/*#__SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"4
M`P``3*#__U,`````00X(A@)!#@R#`TX.'$@.($X.'$(.($8.'$<.&$(.'$$.
M($$.)$<.*$<.+$$.,$@.#$'##@A!Q@X$``"0````X`,``&"@___)`````$$.
M"(4"00X,AP-!#A"&!$$.%(,%40ZP0%T.N$!!#KQ`00[`0$<.Q$!%#LA`0@[,
M0$4.T$!(#K!`1PZT0$4.N$!(#KQ`00[`0$@.L$!,#KQ`00[`0$@.L$!)#K1`
M00ZX0$$.O$!!#L!`3`ZP0%@*#A1!PPX00<8.#$''#@A!Q0X$2PL`$````'0$
M``"<H/__!0````````#X````B`0``)B@__\=`@```$$."(4"00X,AP-!#A"&
M!$$.%(,%40[`('0.R"!$#LP@00[0($@.P"!P"@X40<,.$$'&#@Q!QPX(0<4.
M!$$+0P[,($0.T"!&#LP@00[(($T.S"!!#M`@30[`(&@.R"!!#LP@00[0($@.
MP"!+#LP@00[0($@.P"!T#L0@1`[(($$.S"!'#M`@00[4($4.V"!"#MP@10[@
M($@.S"!&#M`@2`[$($8.R"!!#LP@0@[0($@.P"!'#LP@0@[0($X.P"!/#L@@
M1`[,($(.T"!(#L`@`DD.R"!"#LP@00[0($@.P"!4#LP@00[0($@.P"`0````
MA`4``+RA__\B`````````'````"8!0``V*'__^P`````00X(A@)!#@R#`TX.
M(%8.+$$.,$P.('@.+$(.,$@.($\*#@Q!PPX(0<8.!$H+80XD00XH00XL1PXP
M2`X@10H.#$'##@A!Q@X$1PM#"@X,0\,."$'&#@1!"TD.+$$.,$@.(```-```
M``P&``!4HO__V0$```!!#@B'`D$.#(8#00X0@P1.#D`#=@$*#A!!PPX,0<8.
M"$''#@1&"P`@````1`8``/RC__]Y`````$$."(,"3@X@9PH."$'##@1)"P`H
M````:`8``%BD__\T`````$$."(,"3@X02`X<00X@2`X020H."$'##@1&"W``
M``"4!@``;*3__UH!````00X(A0)!#@R'`T$.$(8$00X4@P5.#G`"@0YX1`Y\
M00Z``4P.<`)&"@X40<,.$$'&#@Q!QPX(0<4.!$(+0PY\1`Z``6P.=$4.>$0.
M?$0.@`%$#H0!0@Z(`4(.C`%!#I`!3`YPY`,```@'``!8I?__*0T```!!#@B%
M`D$.#(<#00X0A@1!#A2#!5$.T(("`L(.W(("0P[@@@)8#M""`EP.W(("1@[@
M@@)$#N2"`D(.Z(("0@[L@@)!#O""`DL.T(("?P[<@@)##N""`D@.T((";`[<
M@@)!#N""`DH.T(("5`[<@@)##N""`D@.T(("?P[<@@)(#N""`E4.Y(("00[H
M@@)+#NR"`D<.\(("0P[T@@)"#OB"`D(._(("00Z`@P)(#MB"`D4.W(("00[@
M@@)(#M""`E(.W(("1`[@@@)(#M2"`D8.V(("1`[<@@)"#N""`DP.T(("2P[<
M@@)&#N""`D8.Y(("1P[H@@)(#NR"`D(.\(("2`[0@@)F"@X40<,.$$'&#@Q!
MQPX(0<4.!$L+4P[8@@)!#MR"`D0.X(("1@[D@@)'#NB"`D@.[(("0@[P@@)(
M#M""`E0.W(("0@[@@@).#M""`E,.W(("0@[@@@)7#M""`DP.W(("0@[@@@).
M#M""`E,.W(("0P[@@@);#M""`DL.W(("0P[@@@)&#MR"`D$.V(("00[<@@)&
M#N""`DP.T(("2P[<@@)'#N""`D@.T(("?@[8@@)$#MR"`D0.X(("3`[0@@)M
M#M2"`D$.V(("2@[<@@)$#N""`D$.Y(("0@[H@@)"#NR"`D0.\(("2`[0@@)R
M#MR"`D0.X(("00[D@@)!#NB"`D0.[(("1`[P@@)$#O2"`D(.^(("0@[\@@)!
M#H"#`D@.T(("0P[8@@)'#MR"`D$.X(("2`[0@@)(#MR"`D8.X(("80[0@@)+
M#MR"`D,.X(("7`[0@@)T#MR"`D,.X(("2`[0@@).#MR"`DH.X(("3`[0@@);
M#M2"`D(.V(("0@[<@@)%#N""`D@.U(("0@[8@@),#MR"`D$.X(("2`[0@@):
M#M2"`D(.V(("1`[<@@)$#N""`@*M#M""`EH.U(("10[8@@)$#MR"`D0.X(("
M3`[0@@("E@[4@@)!#MB"`D0.W(("00[@@@)<#M""`@,/`0[4@@)!#MB"`D$.
MW(("1`[@@@)3#M""`GL.W(("1`[@@@("0@[0@@(##`(.W(("0P[@@@)$#N2"
M`D(.Z(("0@[L@@)!#O""`DL.T(("5P[4@@)*#MB"`D0.W(("1`[@@@)!#N2"
M`D(.Z(("0@[L@@)$#O""`D@.T(("5P[<@@)##N""`DP.T(("`MD.U(("0@[8
M@@)"#MR"`D4.X(("2`[4@@)"#MB"`D4.W(("00[@@@),#N2"`D<.Z(("1`[L
M@@)$#O""`D$.](("0@[X@@)"#OR"`D0.@(,"2`[0@@(``'`!``#P"@``H*[_
M_X`#````00X(A0)!#@R'`T$.$(8$00X4@P5.#DQ5#E!&#DQ##E!F#D!5#DQ#
M#E!-#E1"#EA!#EQ!#F!(#D!O#DA!#DQ)#E!(#D!7#DQ##E!'#E1!#EA$#EQ!
M#F!(#D!<#DQ##E!'#E1"#EA%#EQ!#F!(#D!7#DQ##E!-#E1"#EA!#EQ!#F!(
M#D!,#DQ%#E!.#D1!#DA!#DQ!#E!+#D!/#DQ##E!-#E1"#EA!#EQ!#F!(#D!E
M#DQ%#E!(#D1!#DA!#DQ!#E!(#D!##DQ##E!.#D1"#DA!#DQ!#E!(#DQ##E!.
M#D1!#DA!#DQ!#E!&#DQ##E!;#D!3#DA%#DQ!#E!+#D!B"@X40<,.$$'&#@Q!
MQPX(0<4.!$D+6PY,0PY020Y,00Y(00Y,00Y02`Y`80H.3$8.4$@.0%D.3$$.
M4$4+20Y,2@Y040Y`2`Y,0PY01@Y,00Y(00Y,00Y02`Y`2PY$1PY(0@Y,1PY0
M`$P```!D#```K+#__WL`````00X(AP)!#@R&`T$.$(,$4@X<00X@2PX0>@X8
M00X<00X@2`X010K##@Q!Q@X(0<<.!$$+1<,.#$/&#@A!QPX$1````+0,``#L
M9O__0`(```!$#`$`1Q`%`G4`1@\#=7`&$`<"=7P0!@)U>!`#`G5T`WL!"L$,
M`0!!PT'&0<=!Q4,,!`1!"P``$````/P,``"/L/__!``````````P````$`T`
M`("P__\\`````$$."(,"3@X030X41`X81`X<1`X@2`X(0<,.!$<.$(,"````
M2````$0-``",L/__70````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.(&D.)$0.
M*$0.+$$.,$T.($<.%$'##A!!Q@X,0<<."$'%#@0``!````"0#0``H+#__P(`
M````````&````*0-``"<L/__%`````!!#@B#`DX.$```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(`7```P%P````````$````!`````0```-\!```!````
MZ@$```$```#T`0```0```$,"```!````H`,```P```#L$0``#0```,1>```9
M````N,T``!L````$````&@```+S-```<````!````/7^_V^L`0``!0```/P(
M```&````C`(```H````2!0``"P```!`````5``````````,```#,S@``$0``
M`'P/```2````<`(``!,````(````&`````````#[__]O`0``"/[__V_<#@``
M____;P(```#P__]O#@X``/K__V\%````````````````````````````````
M`````````````````````````,3-````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````0%```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````30``#_____!&(``$=#0SH@*$1E8FEA;B`V+C(N
M,"TT*2`V+C(N,"`R,#$V,#DQ-```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+FEN:70`+G!L=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ
M8W(`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````
M```````````````````````````````````````+`````0````(```!4`0``
M5`$``!,```````````````$`````````$P````<````"````:`$``&@!```@
M```````````````$`````````"$````'`````@```(@!``"(`0``)```````
M````````!``````````T````]O__;P(```"L`0``K`$``.`````%````````
M``0````$````/@````L````"````C`(``(P"``!P!@``!@````$````$````
M$````$8````#`````@```/P(``#\"```$@4``````````````0````````!.
M````____;P(````.#@``#@X``,X````%``````````(````"````6P```/[_
M_V\"````W`X``-P.``"@````!@````(````$`````````&H````)`````@``
M`'P/``!\#P``<`(```4`````````!`````@```!S`````0````8```#L$0``
M[!$``",```````````````0`````````>0````$````&````$!(``!`2```0
M```````````````0````!````'X````!````!@```"`2```@$@``\`$`````
M````````"`````````"'`````0````8````0%```$!0``+1*````````````
M`!``````````C0````$````&````Q%X``,1>```4```````````````$````
M`````),````!`````@```-A>``#87@``J$``````````````!`````````";
M`````0````(```"`GP``@)\``.P```````````````0`````````J0````$`
M```"````;*```&R@``#`#0`````````````$`````````+,````.`````P``
M`+C-``"XO0``!```````````````!`````0```"_````#P````,```"\S0``
MO+T```0```````````````0````$````RP````$````#````P,T``,"]```$
M```````````````$`````````-`````&`````P```,3-``#$O0``"`$```8`
M````````!`````@```""`````0````,```#,S@``S+X``#0!````````````
M``0````$````V0````$````#`````-````#````0```````````````$````
M`````-\````(`````P```"#0```0P```-!``````````````(`````````#D
M`````0```#``````````$,```"4```````````````$````!`````0````,`
B`````````````#7```#M```````````````!````````````
